pub trait FileTypeExt {
// Required methods
fn is_symlink_dir(&self) -> bool;
fn is_symlink_file(&self) -> bool;
}โ This trait cannot be implemented outside
std.Available on Windows only.
Windows-specific extensions to fs::FileType.
On Windows, a symbolic link knows whether it is a file or directory.
Required Methods
1.64.0 ยท Sourcefn is_symlink_dir(&self) -> bool
fn is_symlink_dir(&self) -> bool
Returns true if this file type is a symbolic link that is also a directory.
1.64.0 ยท Sourcefn is_symlink_file(&self) -> bool
fn is_symlink_file(&self) -> bool
Returns true if this file type is a symbolic link that is also a file.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".